@@ -55,7 +55,7 @@ system("rm -rf qgvtp*");
 
 $cmd = "svn export $repo $basedir";
 system($cmd);
-system("cp $basedir/icons/qgv.png $basedir/src/qgvdial.png");
+system("cp $basedir/icons/64/qgvdial.png $basedir/src/qgvdial.png");
 
 # Append the version to the pro file
 open(PRO_FILE, ">>$basedir/src/src.pro") || die "Cannot open pro file";
