@@ -42,3 +42,10 @@ MobileWebPage::setUA (bool bSetIphone /*= false*/)
 {
     bUAIsIphone = bSetIphone;
 }//MobileWebPage::setUA
+
+QWebPage *
+MobileWebPage::createWindow (QWebPage::WebWindowType /*type*/)
+{
+    qWarning("Webpage requested a new page");
+    return NULL;
+}//MobileWebPage::createWindow
